admin
==================================================
**Module**: :mod:`espressodb.base.admin`

.. currentmodule:: espressodb.base.admin

.. autosummary::
    BaseAdmin
    ListViewAdmin
    register_admins

----

.. automodule:: espressodb.base.admin
    :members:
    :special-members:
